summaryrefslogtreecommitdiffstats
path: root/lib/kformula/glyphelement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kformula/glyphelement.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/glyphelement.h')
-rw-r--r--lib/kformula/glyphelement.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/lib/kformula/glyphelement.h b/lib/kformula/glyphelement.h
index 425caf10..dd6c6e8c 100644
--- a/lib/kformula/glyphelement.h
+++ b/lib/kformula/glyphelement.h
@@ -27,11 +27,11 @@ KFORMULA_NAMESPACE_BEGIN
class GlyphElement : public TextElement {
typedef TextElement inherited;
public:
- GlyphElement( BasicElement* parent = 0 );
+ GlyphElement( BasicElement* tqparent = 0 );
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -39,27 +39,27 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
protected:
- virtual bool readAttributesFromMathMLDom( const QDomElement &element );
+ virtual bool readAttributesFromMathMLDom( const TQDomElement &element );
private:
- virtual QString getElementName() const { return "mglyph"; }
- virtual void writeMathMLAttributes( QDomElement& element ) const ;
+ virtual TQString getElementName() const { return "mglyph"; }
+ virtual void writeMathMLAttributes( TQDomElement& element ) const ;
- QChar m_char; // Char to be shown
- QString m_fontFamily; // Font family to use
- QString m_alt; // Alternative text if font family not found
+ TQChar m_char; // Char to be shown
+ TQString m_fontFamily; // Font family to use
+ TQString m_alt; // Alternative text if font family not found
bool m_hasFont; // Whether required font is available
};
@@ -39,27 +39,27 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/